Magic class

Bindings for libmagic.

Constructors

Magic(DynamicLibrary dynamicLibrary)
The symbols are looked up in dynamicLibrary.
Magic.fromLookup(Pointer<T> lookup<T extends NativeType>(String symbolName))
The symbols are looked up with lookup.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

magic_buffer(magic_t arg0, Pointer<Void> arg1, int arg2) Pointer<Char>
magic_check(magic_t arg0, Pointer<Char> arg1) int
magic_close(magic_t arg0) → void
magic_compile(magic_t arg0, Pointer<Char> arg1) int
magic_descriptor(magic_t arg0, int arg1) Pointer<Char>
magic_errno(magic_t arg0) int
magic_error(magic_t arg0) Pointer<Char>
magic_file(magic_t arg0, Pointer<Char> arg1) Pointer<Char>
magic_getflags(magic_t arg0) int
magic_getparam(magic_t arg0, int arg1, Pointer<Void> arg2) int
magic_getpath(Pointer<Char> arg0, int arg1) Pointer<Char>
magic_list(magic_t arg0, Pointer<Char> arg1) int
magic_load(magic_t arg0, Pointer<Char> arg1) int
magic_load_buffers(magic_t arg0, Pointer<Pointer<Void>> arg1, Pointer<Size> arg2, int arg3) int
magic_open(int arg0) magic_t
magic_setflags(magic_t arg0, int arg1) int
magic_setparam(magic_t arg0, int arg1, Pointer<Void> arg2) int
magic_version() int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited